// The main module of the tumblr Add-on.

var toolbarbutton = require("toolbarbutton");
var widgets = require("sdk/widget");
var tabs = require("sdk/tabs");
var ss = require("sdk/simple-storage");
var data = require("self").data;

exports.main = function(options) {
    var auth_tab;
    var pageMod = require("sdk/page-mod");

    pageMod.PageMod({
        include: "*.tumblr.com",
        contentScriptFile: data.url("auth.js"),
        onAttach: function(worker) {
            worker.port.on("auth_save", function(message) {
                ss.storage.user_email = message.email;
                ss.storage.ext_key = message.key;
                worker.port.emit("auth_save_success");
            });
            worker.port.on("close_tab", function() {
                if (typeof auth_tab !== "undefined") {
                    auth_tab.close();
                }
            });
        }
    });

    var tumblrPanel = require("sdk/panel").Panel({
        width: 452,
        height: 432,
        contentURL: data.url("popup.html"),
        contentScriptFile: data.url("panel.js")
    });

    tumblrPanel.port.on("reauth", function() {
        var url = "https://www.tumblr.com/ext_authorize?key_note=Firefox%20Extension";
        tabs.open({
            url: url,
            onOpen: function(tab) {
                auth_tab = tab;
            }
        });
        tumblrPanel.hide();
    });

    tumblrPanel.port.on("close", function() {
        tumblrPanel.hide();
    });

    tumblrPanel.on("show", function() {
        var tab = tabs.activeTab;
        worker = tab.attach({
            contentScriptFile: data.url("page.js")
        });
        worker.port.on("returnPageInfo", function(arg) {
            tumblrPanel.port.emit("tabInfo", {
                user_email: ss.storage.user_email,
                ext_key: ss.storage.ext_key,
                url: tabs.activeTab.url,
                title: tabs.activeTab.title,
                selection: arg.selection
            });
        });
    });

    tumblrPanel.on("hide", function() {
        tumblrPanel.port.emit("reset");
    });

    // widget
    // widgets.Widget({
    //     id: "Tumblr",
    //     label: "Share on Tumblr",
    //     contentURL: "http://www.tumblr.com/favicon.ico",
    //     panel: tumblrPanel
    // });

    // toolbar button
    var tbb = toolbarbutton.ToolbarButton({
        id: "Tumblr",
        label: "Share on Tumblr",
        image: "http://www.tumblr.com/favicon.ico",
        panel: tumblrPanel
    });

    if (options.loadReason == "install") {
        tbb.moveTo({
            toolbarID: "nav-bar",
            forceMove: true
        });
    }
};
